@@ -1,4 +1,6 @@
+import logging
 from dataclasses import dataclass, field
+from typing import Union
 
 from httpx._config import Timeout
 from httpx._types import TimeoutTypes
@@ -12,6 +14,8 @@ from ..models.wallets import Wallet, Wallets
 from ..models.webhooks import Webhook, Webhooks
 from ..utils import validate_response
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class TelePayAsyncClient:
@@ -50,10 +54,13 @@ class TelePayAsyncClient:
         Info about the current account
         """
         response = await self.http_client.get("getMe")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Account.from_json(response.json())
 
-    async def get_balance(self, asset=None, blockchain=None, network=None) -> Wallets:
+    async def get_balance(
+        self, asset=None, blockchain=None, network=None
+    ) -> Union[Wallet, Wallets]:
         """
         Get your merchant wallet assets with corresponding balance
         """
@@ -62,10 +69,12 @@ class TelePayAsyncClient:
                 "getBalance",
                 json={"asset": asset, "blockchain": blockchain, "network": network},
             )
+            logger.debug(f"Response: {response.text}")
             validate_response(response)
-            return Wallet.from_json(response.json())
+            return Wallets.from_json(response.json())
         else:
             response = await self.http_client.get("getBalance")
+            logger.debug(f"Response: {response.text}")
             validate_response(response)
             return Wallets.from_json(response.json())
 
@@ -81,6 +90,7 @@ class TelePayAsyncClient:
                 "blockchain": blockchain,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Asset.from_json(response.json())
 
@@ -89,6 +99,7 @@ class TelePayAsyncClient:
         Get assets suported by TelePay
         """
         response = await self.http_client.get("getAssets")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Assets.from_json(response.json())
 
@@ -97,6 +108,7 @@ class TelePayAsyncClient:
         Get your merchant invoices
         """
         response = await self.http_client.get("getInvoices")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return InvoiceList.from_json(response.json())
 
@@ -105,6 +117,7 @@ class TelePayAsyncClient:
         Get invoice details, by ID
         """
         response = await self.http_client.get(f"getInvoice/{number}")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Invoice.from_json(response.json())
 
@@ -137,6 +150,7 @@ class TelePayAsyncClient:
                 "expires_at": expires_at,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Invoice.from_json(response.json())
 
@@ -145,6 +159,7 @@ class TelePayAsyncClient:
         Cancel an invoice
         """
         response = await self.http_client.post(f"cancelInvoice/{number}")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Invoice.from_json(response.json())
 
@@ -153,6 +168,7 @@ class TelePayAsyncClient:
         Delete an invoice
         """
         response = await self.http_client.post(f"deleteInvoice/{number}")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return response.json()
 
@@ -180,6 +196,7 @@ class TelePayAsyncClient:
                 "message": message,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return response.json()
 
@@ -200,6 +217,7 @@ class TelePayAsyncClient:
                 "network": network,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return response.json()
 
@@ -226,6 +244,7 @@ class TelePayAsyncClient:
                 "message": message,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return response.json()
 
@@ -253,6 +272,7 @@ class TelePayAsyncClient:
                 "message": message,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return response.json()
 
@@ -271,6 +291,7 @@ class TelePayAsyncClient:
                 "active": active,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Webhook.from_json(response.json())
 
@@ -289,6 +310,7 @@ class TelePayAsyncClient:
                 "active": active,
             },
         )
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Webhook.from_json(response.json())
 
@@ -313,6 +335,7 @@ class TelePayAsyncClient:
         Delete a webhook
         """
         response = await self.http_client.post(f"deleteWebhook/{id}")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return response.json()
 
@@ -321,6 +344,7 @@ class TelePayAsyncClient:
         Get webhook
         """
         response = await self.http_client.get(f"getWebhook/{id}")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Webhook.from_json(response.json())
 
@@ -329,5 +353,6 @@ class TelePayAsyncClient:
         Get webhooks
         """
         response = await self.http_client.get("getWebhooks")
+        logger.debug(f"Response: {response.text}")
         validate_response(response)
         return Webhooks.from_json(response.json())
