@@ -1,8 +1,11 @@
+import logging
 from dataclasses import dataclass
 from typing import Any
 
 from ..utils import parse_json
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class Account:
@@ -14,4 +17,5 @@ class Account:
     @classmethod
     def from_json(cls, json: Any) -> "Account":
         del json["version"]
+        logger.debug(f"Parsing Account from JSON: {json}")
         return parse_json(cls, **json)
