@@ -1,8 +1,11 @@
+import logging
 from dataclasses import dataclass
 from typing import Any, List
 
 from ..utils import parse_json
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class Asset:
@@ -27,4 +30,5 @@ class Assets:
 
     @classmethod
     def from_json(cls, json: Any) -> "Assets":
+        logger.debug(f"Parsing Assets from JSON: {json}")
         return parse_json(cls, **json)
