@@ -1,8 +1,11 @@
+import logging
 from dataclasses import dataclass
 from typing import Any, List
 
 from ..utils import parse_json
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class Wallet:
@@ -13,6 +16,7 @@ class Wallet:
 
     @classmethod
     def from_json(cls, json: Any) -> "Wallet":
+        logger.debug(f"Parsing wallet from JSON: {json}")
         return parse_json(cls, **json)
 
 
@@ -25,4 +29,5 @@ class Wallets:
 
     @classmethod
     def from_json(cls, json: Any) -> "Wallets":
+        logger.debug(f"Parsing wallets from JSON: {json}")
         return parse_json(cls, **json)
