@@ -1,8 +1,11 @@
+import logging
 from dataclasses import dataclass
 from typing import Any, List
 
 from ..utils import parse_json
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass
 class Webhook:
@@ -14,6 +17,7 @@ class Webhook:
 
     @classmethod
     def from_json(cls, json: Any) -> "Webhook":
+        logger.debug(f"Parsing Webhook from JSON: {json}")
         return parse_json(cls, **json)
 
 
@@ -26,4 +30,5 @@ class Webhooks:
 
     @classmethod
     def from_json(cls, json: Any) -> "Webhooks":
+        logger.debug(f"Parsing Webhooks from JSON: {json}")
         return parse_json(cls, **json)
